pub struct NextKey(/* private fields */);Expand description
Fetching the key that follows a given one in the parent storage is required in order to continue.
Implementations
Sourceimpl NextKey
impl NextKey
Sourcepub fn key(&self) -> impl Iterator<Item = Nibble>
pub fn key(&self) -> impl Iterator<Item = Nibble>
Returns the key whose next key must be passed back.
Sourcepub fn child_trie(&self) -> Option<impl AsRef<[u8]>>
pub fn child_trie(&self) -> Option<impl AsRef<[u8]>>
If Some, read from the given child trie. If None, read from the main trie.
Sourcepub fn or_equal(&self) -> bool
pub fn or_equal(&self) -> bool
If true, then the provided value must the one superior or equal to the requested key.
If false, then the provided value must be strictly superior to the requested key.
Sourcepub fn branch_nodes(&self) -> bool
pub fn branch_nodes(&self) -> bool
If true, then the search must include both branch nodes and storage nodes. If false,
the search only covers storage nodes.
Sourcepub fn prefix(&self) -> impl Iterator<Item = Nibble>
pub fn prefix(&self) -> impl Iterator<Item = Nibble>
Returns the prefix the next key must start with. If the next key doesn’t start with the
given prefix, then None should be provided.
Sourcepub fn inject_key(
self,
key: Option<impl Iterator<Item = Nibble>>,
) -> BuilderAuthoring
pub fn inject_key( self, key: Option<impl Iterator<Item = Nibble>>, ) -> BuilderAuthoring
Injects the key.
Panic
Panics if the key passed as parameter isn’t strictly superior to the requested key.