OutputUpdate

Enum OutputUpdate 

pub enum OutputUpdate<TBl, TAsync> {
    Finalized {
        former_index: NodeIndex,
        user_data: TBl,
        former_finalized_async_op_user_data: TAsync,
        best_output_block_updated: bool,
        pruned_blocks: Vec<(NodeIndex, TBl, Option<TAsync>)>,
    },
    Block(OutputUpdateBlock),
    BestBlockChanged {
        best_block_index: Option<NodeIndex>,
    },
}
Variants



Finalized

A non-finalized block has been finalized in the output.

This block is no longer part of the data structure.

Blocks are guaranteed to be finalized one after the other, without any gap.

Fields

former_index: NodeIndex

Index of the node within the data structure. This index is no longer valid and is here for reference.

user_data: TBl

User data associated to this block.

former_finalized_async_op_user_data: TAsync

User data associated to the async operation of the previous finalized block.

best_output_block_updated: bool

true if the finalization has updated the best output block.

pruned_blocks: Vec<(NodeIndex, TBl, Option<TAsync>)>

Blocks that were a descendant of the former finalized block but not of the new finalized block. These blocks are no longer part of the data structure.

If the Option<TAsync> is Some, then that block was part of the output. Otherwise it wasn’t.



Block(OutputUpdateBlock)

A new block has been added to the list of output unfinalized blocks.



BestBlockChanged

The output best block has been modified.

Fields

best_block_index: Option<NodeIndex>

Index of the best block after the finalization. None if the best block is the output finalized block.