pub fn hash_api_name(api_name: &str) -> [u8; 8]Expand description
Hashes the name of an API in order to be able to compare it to CoreVersionApi::name_hash.
pub fn hash_api_name(api_name: &str) -> [u8; 8]Hashes the name of an API in order to be able to compare it to CoreVersionApi::name_hash.