CoreVersionRef

Struct CoreVersionRef 

pub struct CoreVersionRef<'a> {
    pub spec_name: &'a str,
    pub impl_name: &'a str,
    pub authoring_version: u32,
    pub spec_version: u32,
    pub impl_version: u32,
    pub apis: CoreVersionApisRefIter<'a>,
    pub transaction_version: Option<u32>,
    pub state_version: Option<TrieEntryVersion>,
}
Runtime specification, once decoded.

Fields

spec_name: &'a strimpl_name: &'a strauthoring_version: u32spec_version: u32impl_version: u32apis: CoreVersionApisRefIter<'a>

List of “API“s that the runtime supports.

Each API corresponds to a certain list of runtime entry points.

This field can thus be used in order to determine which runtime entry points are available.

transaction_version: Option<u32>

Arbitrary version number corresponding to the transactions encoding version.

Whenever this version number changes, all transactions encoding generated earlier are invalidated and should be regenerated.

Older versions of Substrate didn’t provide this field. None if the field is missing.

state_version: Option<TrieEntryVersion>

Version number of the state trie encoding version.

Version 0 corresponds to a different trie encoding than version 1.

This field has been added to Substrate on 24th December 2021. Older versions of Substrate didn’t provide this field, in which case it will contain None.

None should be interpreted the same way as Some(0).

Implementations

Source

impl CoreVersionRef<'_>

pub fn scale_encoding_vec(&self) -> Vec<u8>

Returns the SCALE encoding of this data structure.