pub enum OffchainContext {
StorageGet(OffchainStorageGet),
StorageSet(OffchainStorageCompareSet),
Timestamp(OffchainTimestamp),
RandomSeed(OffchainRandomSeed),
SubmitTransaction(OffchainSubmitTransaction),
}Variants
StorageGet(OffchainStorageGet)
Loading an offchain storage value is required in order to continue.
StorageSet(OffchainStorageCompareSet)
Setting an offchain storage value is required in order to continue.
Contrary to RuntimeCall::OffchainStorageSet, this variant can only happen in offchain
workers.
Timestamp(OffchainTimestamp)
Timestamp for offchain worker.
RandomSeed(OffchainRandomSeed)
Random seed for offchain worker.
SubmitTransaction(OffchainSubmitTransaction)
Submit transaction from offchain worker.
Implementations
Sourceimpl OffchainContext
impl OffchainContext
pub fn into_prototype(self) -> HostVmPrototype