pub struct Config<'a, TParams> {
pub virtual_machine: HostVmPrototype,
pub function_to_call: &'a str,
pub parameter: TParams,
pub storage_main_trie_changes: TrieDiff,
pub storage_proof_size_behavior: StorageProofSizeBehavior,
pub max_log_level: u32,
pub calculate_trie_changes: bool,
}Expand description
Configuration for run.
Fields
virtual_machine: HostVmPrototypeVirtual machine to be run.
function_to_call: &'a strName of the function to be called.
parameter: TParamsParameter of the call, as an iterator of bytes. The concatenation of bytes forms the actual input.
storage_main_trie_changes: TrieDiffInitial state of Success::storage_changes. The changes made during this
execution will be pushed over the value in this field.
storage_proof_size_behavior: StorageProofSizeBehaviorBehavior if the ext_storage_proof_size_storage_proof_size_version_1 host function is
called.
See the documentation of StorageProofSizeBehavior.
max_log_level: u32Maximum log level of the runtime.
Note: This value is opaque from the point of the view of the client, and the runtime is free to interpret it the way it wants. However, usually values are:
0for “off”,1for “error”,2for “warn”,3for “info”,4for “debug”, and5for “trace”.
calculate_trie_changes: boolIf true, then StorageChanges::trie_changes_iter_ordered will return Some.
Passing None requires fewer calculation and fewer storage accesses.