pub struct OffchainStorageGet { /* private fields */ }Expand description
Loading an offchain storage value is required in order to continue.
Implementations
Sourceimpl OffchainStorageGet
impl OffchainStorageGet
Sourcepub fn key(&self) -> impl AsRef<[u8]>
pub fn key(&self) -> impl AsRef<[u8]>
Returns the key whose value must be passed to OffchainStorageGet::inject_value.
Sourcepub fn inject_value(self, value: Option<impl AsRef<[u8]>>) -> RuntimeCall
pub fn inject_value(self, value: Option<impl AsRef<[u8]>>) -> RuntimeCall
Injects the corresponding storage value.