ExecHint

Enum ExecHint 

pub enum ExecHint {
    ValidateAndCompile,
    CompileWithNonDeterministicValidation,
    ValidateAndExecuteOnce,
    ExecuteOnceWithNonDeterministicValidation,
    Untrusted,
    ForceWasmi {
        lazy_validation: bool,
    },
    ForceWasmtime,
}
Hint used by the implementation to decide which kind of virtual machine to use.

Variants



ValidateAndCompile

The WebAssembly code will be instantiated once and run many times. If possible, compile this WebAssembly code ahead of time.



CompileWithNonDeterministicValidation

The WebAssembly code will be instantiated once and run many times. Contrary to ExecHint::ValidateAndCompile, the WebAssembly code isn’t fully validated ahead of time, meaning that invalid WebAssembly modules might successfully be compiled, which is an indesirable property in some contexts.



ValidateAndExecuteOnce

The WebAssembly code is expected to be only run once.

Note: This isn’t a hard requirement but a hint.



ExecuteOnceWithNonDeterministicValidation

The WebAssembly code will be instantiated once and run many times. Contrary to ExecHint::ValidateAndExecuteOnce, the WebAssembly code isn’t fully validated ahead of time, meaning that invalid WebAssembly modules might successfully be compiled, which is an indesirable property in some contexts.



Untrusted

The WebAssembly code running through this VM is untrusted.



ForceWasmi

Forces using the wasmi backend.

This variant is useful for testing purposes.

Fields

lazy_validation: bool

If true, lazy validation is enabled. This leads to a faster initialization time, but can also successfully validate invalid modules, which is an indesirable property in some contexts.



ForceWasmtime

Forces using the wasmtime backend.

This variant is useful for testing purposes.

Implementations

Source

impl ExecHint

pub fn available_engines() -> impl Iterator<Item = ExecHint>

Returns an iterator of all the ExecHint values corresponding to execution engines.

Note: This function is most useful for testing purposes.

pub fn force_wasmtime_if_available() -> Option<ExecHint>

Returns ForceWasmtime if it is available on the current platform, and None otherwise.