ExecOutcome

Enum ExecOutcome 

pub enum ExecOutcome {
    Finished {
        return_value: Result<Option<WasmValue>, Trap>,
    },
    Interrupted {
        id: usize,
        params: Vec<WasmValue>,
    },
}
Outcome of the run function.

Variants



Finished

The execution has finished.

The state machine is now in a poisoned state, and calling run will return RunErr::Poisoned.

Fields

return_value: Result<Option<WasmValue>, Trap>

Return value of the function.



Interrupted

The virtual machine has been paused due to a call to a host function.

This variant contains the identifier of the host function that is expected to be called, and its parameters. When you call run again, you must pass back the outcome of calling that function.

Note: The type of the return value of the function is called is not specified, as the user is supposed to know it based on the identifier. It is an error to call run with a value of the wrong type.

Fields

id: usize

Identifier of the function to call. Corresponds to the value provided at initialization when resolving imports.

params: Vec<WasmValue>

Parameters of the function call.