pub enum StartErr {
FunctionNotFound,
NotAFunction,
SignatureNotSupported,
InvalidParameters,
}Expand description
Error that can happen when calling Prepare::start.
Variants
FunctionNotFound
Couldn’t find the requested function.
NotAFunction
The requested function has been found in the list of exports, but it is not a function.
SignatureNotSupported
The requested function has a signature that isn’t supported.
InvalidParameters
The types of the provided parameters don’t match the signature.