pub enum WasmValue {
I32(i32),
I64(i64),
}Expand description
Value that a Wasm function can accept or produce.
Variants
I32(i32)
A 32-bits integer. There is no fundamental difference between signed and unsigned integer, and the signed-ness should be determined depending on the context.
I64(i64)
A 32-bits integer. There is no fundamental difference between signed and unsigned integer, and the signed-ness should be determined depending on the context.
Implementations