Config

Struct Config 

pub struct Config<'a> {
    pub module_bytes: &'a [u8],
    pub exec_hint: ExecHint,
    pub symbols: &'a mut dyn FnMut(&str, &str, &Signature) -> Result<usize, ()>,
}
Configuration to pass to VirtualMachinePrototype::new.

Fields

module_bytes: &'a [u8]

Encoded wasm bytecode.

exec_hint: ExecHint

Hint about how to execute the WebAssembly code.

symbols: &'a mut dyn FnMut(&str, &str, &Signature) -> Result<usize, ()>

Called for each import that the module has. It must assign a number to each import, or return an error if the import can’t be resolved. When the VM calls one of these functions, this number will be returned back in order for the user to know how to handle the call.