Prepare

Struct Prepare 

pub struct Prepare { /* private fields */ }

Implementations

Source

impl Prepare

pub fn into_prototype(self) -> VirtualMachinePrototype

Turns back this virtual machine into a prototype.

pub fn memory_size(&self) -> HeapPages

Returns the size of the memory, in bytes.

pub fn read_memory( &self, offset: u32, size: u32, ) -> Result<impl AsRef<[u8]>, OutOfBoundsError>

Copies the given memory range into a Vec<u8>.

Returns an error if the range is invalid or out of range.

pub fn write_memory( &mut self, offset: u32, value: &[u8], ) -> Result<(), OutOfBoundsError>

Write the data at the given memory location.

Returns an error if the range is invalid or out of range.

pub fn grow_memory( &mut self, additional: HeapPages, ) -> Result<(), OutOfBoundsError>

Increases the size of the memory by the given number of pages.

Returns an error if the size of the memory can’t be expanded more. This can be known ahead of time by using VirtualMachinePrototype::memory_max_pages.

pub fn start( self, function_name: &str, params: &[WasmValue], ) -> Result<VirtualMachine, (StartErr, VirtualMachinePrototype)>

Turns this prototype into an actual virtual machine. This requires choosing which function to execute.