pub struct Signature { /* private fields */ }Expand description
Low-level Wasm function signature.
Implementations
Sourceimpl Signature
impl Signature
Sourcepub fn new(
params: impl Iterator<Item = ValueType>,
ret_ty: impl Into<Option<ValueType>>,
) -> Signature
pub fn new( params: impl Iterator<Item = ValueType>, ret_ty: impl Into<Option<ValueType>>, ) -> Signature
Creates a Signature from the given parameter types and return type.
Sourcepub fn parameters(&self) -> impl ExactSizeIterator<Item = &ValueType>
pub fn parameters(&self) -> impl ExactSizeIterator<Item = &ValueType>
Returns a list of all the types of the parameters.
Sourcepub fn return_type(&self) -> Option<&ValueType>
pub fn return_type(&self) -> Option<&ValueType>
Returns the type of the return type of the function. None means “void”.