VirtualMachine

Struct VirtualMachine 

pub struct VirtualMachine { /* private fields */ }

Implementations

Source

impl VirtualMachine

pub fn run(&mut self, value: Option<WasmValue>) -> Result<ExecOutcome, RunErr>

Starts or continues execution of this thread.

If this is the first call you call run for this thread, then you must pass a value of None. If, however, you call this function after a previous call to run that was interrupted by a host function call, then you must pass back the outcome of that call.

pub fn memory_size(&self) -> HeapPages

Returns the size of the memory, in bytes.

Note: This can change over time if the Wasm code uses the grow opcode.

pub fn read_memory( &self, offset: u32, size: u32, ) -> Result<impl AsRef<[u8]>, OutOfBoundsError>

Copies the given memory range into a Vec<u8>.

Returns an error if the range is invalid or out of range.

pub fn write_memory( &mut self, offset: u32, value: &[u8], ) -> Result<(), OutOfBoundsError>

Write the data at the given memory location.

Returns an error if the range is invalid or out of range.

pub fn grow_memory( &mut self, additional: HeapPages, ) -> Result<(), OutOfBoundsError>

Increases the size of the memory by the given number of pages.

Returns an error if the size of the memory can’t be expanded more. This can be known ahead of time by using VirtualMachinePrototype::memory_max_pages.

pub fn into_prototype(self) -> VirtualMachinePrototype

Turns back this virtual machine into a prototype.