pub enum CommitVerify<C> {
IsAuthority(CommitVerifyIsAuthority<C>),
IsParent(CommitVerifyIsParent<C>),
Finished(Result<(), CommitVerifyError>),
FinishedUnknown,
}Expand description
Commit verification in progress.
Variants
IsAuthority(CommitVerifyIsAuthority<C>)
IsParent(CommitVerifyIsParent<C>)
See CommitVerifyIsParent.
Finished(Result<(), CommitVerifyError>)
Verification is finished. Contains an error if the commit message is invalid.
FinishedUnknown
Verification is finished, but CommitVerifyIsParent::resume has been called with None,
meaning that some signatures couldn’t be verified, and the commit message doesn’t contain
enough signatures that are known to be valid.
The commit must be verified again after more blocks are available.