pub enum BlocksRequestDirection {
Ascending,
Descending,
}Expand description
Whether the first block should be the one with the highest number, of the one with the lowest number.
Variants
Ascending
Blocks should be returned in ascending number, starting from the requested one. In other words, amongst all the blocks in the response, the requested block must be the one with the lowest block number, and all the other blocks are its descendants.
Descending
Blocks should be returned in descending number, starting from the requested one. In other words, amongst all the blocks in the response, the requested block must be the one with the highest block number, and all the other blocks are its ancestors.