pub enum VerifyFragmentError {
JustificationVerify(JustificationVerifyError),
TargetHashMismatch {
justification_target_hash: [u8; 32],
justification_target_height: u64,
header_hash: [u8; 32],
header_height: u64,
},
NonMinimalProof,
BlockNumberNotIncrementing,
EmptyProof,
InvalidHeader(Error),
InvalidJustification(JustificationDecodeError),
}Expand description
Error potentially returned by VerifyWarpSyncFragment::verify.
Variants
JustificationVerify(JustificationVerifyError)
Justification found within the fragment is invalid.
TargetHashMismatch
Mismatch between the block targeted by the justification and the header.
Fields
NonMinimalProof
Warp sync fragment doesn’t contain an authorities list change when it should.
BlockNumberNotIncrementing
Header does not actually advance the warp syncing process. This means that a source has sent a header below the requested hash.
EmptyProof
Warp sync proof is empty.
InvalidHeader(Error)
Failed to decode header.
InvalidJustification(JustificationDecodeError)
Failed to decode justification.