pub struct PrefixScan { /* private fields */ }Expand description
Scan of a prefix in progress.
Implementations
Sourceimpl PrefixScan
impl PrefixScan
Sourcepub fn requested_keys(
&self,
) -> impl Iterator<Item = impl Iterator<Item = Nibble>>
pub fn requested_keys( &self, ) -> impl Iterator<Item = impl Iterator<Item = Nibble>>
Returns the list of keys whose storage proof must be queried.
Sourcepub fn request_storage_values(&self) -> bool
pub fn request_storage_values(&self) -> bool
Returns whether the storage proof must include the storage values of the requested keys.
Note: This is always equal to
Config::full_storage_values_required.
Sourcepub fn resume_all_keys(
self,
proof: &[u8],
) -> Result<ResumeOutcome, (Self, Error)>
pub fn resume_all_keys( self, proof: &[u8], ) -> Result<ResumeOutcome, (Self, Error)>
Injects the proof presumably containing the keys returned by PrefixScan::requested_keys.
Returns an error if the proof is invalid. In that case, self isn’t modified.
Contrary to PrefixScan::resume_partial, a proof is considered valid only if it
fulfills all the keys found in the list returned by PrefixScan::requested_keys.
Sourcepub fn resume_partial(
self,
proof: &[u8],
) -> Result<ResumeOutcome, (Self, Error)>
pub fn resume_partial( self, proof: &[u8], ) -> Result<ResumeOutcome, (Self, Error)>
Injects the proof presumably containing the keys returned by PrefixScan::requested_keys.
Returns an error if the proof is invalid. In that case, self isn’t modified.
Contrary to PrefixScan::resume_all_keys, a proof is considered valid if it advances
the request in any way.