pub enum InvalidChainConfiguration {
ParentEpochStartSlotWithBlockMismatch,
NoCurrentEpochButNextEpochNonZero,
NonZeroNextEpochYetHasStartSlot,
NonGenesisBlockNoCurrentEpoch,
}Expand description
Variants
ParentEpochStartSlotWithBlockMismatch
The start slot of the epoch the parent block belongs to is superior to the slot where the parent block was authored.
NoCurrentEpochButNextEpochNonZero
No current epoch was provided, but the next epoch has an index equal to 0.
NonZeroNextEpochYetHasStartSlot
The next epoch has a non-zero epoch index, but has a start slot.
NonGenesisBlockNoCurrentEpoch
Parent block doesn’t belong to any epoch but is not the genesis block.