pub enum OutputUpdate<TBl, TAsync> {
Finalized {
former_index: NodeIndex,
user_data: TBl,
former_finalized_async_op_user_data: TAsync,
best_output_block_updated: bool,
pruned_blocks: Vec<(NodeIndex, TBl, Option<TAsync>)>,
},
Block(OutputUpdateBlock),
BestBlockChanged {
best_block_index: Option<NodeIndex>,
},
}Expand description
Variants
Finalized
A non-finalized block has been finalized in the output.
This block is no longer part of the data structure.
Blocks are guaranteed to be finalized one after the other, without any gap.
Fields

former_index: NodeIndexIndex of the node within the data structure. This index is no longer valid and is here for reference.

user_data: TBlUser data associated to this block.

former_finalized_async_op_user_data: TAsyncUser data associated to the async operation of the previous finalized block.
Block(OutputUpdateBlock)
A new block has been added to the list of output unfinalized blocks.
BestBlockChanged
The output best block has been modified.