pub enum Bootnode<'a> {
Parsed {
multiaddr: String,
peer_id: Vec<u8>,
},
UnrecognizedFormat(&'a str),
}Expand description
Variants
Parsed
The address of the bootnode is valid.
Fields

multiaddr: StringString representation of the multiaddress that can be used to reach the bootnode.
Does not contain the trailing /p2p/....

peer_id: Vec<u8>Bytes representation of the libp2p peer id of the bootnode.
The format can be found in the libp2p specification: https://github.com/libp2p/specs/blob/master/peer-ids/peer-ids.md
UnrecognizedFormat(&'a str)
The address of the bootnode couldn’t be parsed.
This could be due to the format being invalid, or to smoldot not supporting one of the multiaddress components that is being used.