pub enum Error {
Show 18 variants
Trap(Trap),
AbortOnPanic {
message: String,
},
BadReturnValue {
actual: Option<ValueType>,
},
ReturnedPtrOutOfRange {
pointer: u32,
size: u32,
memory_size: u32,
},
UnresolvedFunctionCalled {
function: String,
module_name: String,
},
ParamDecodeError,
ParamOutOfRange {
function: &'static str,
param_num: usize,
pointer: u32,
length: u32,
},
Utf8Error {
function: &'static str,
param_num: usize,
error: Utf8Error,
},
NoActiveTransaction,
FinishedWithPendingTransaction,
OutOfMemory {
function: &'static str,
requested_size: u32,
},
FreeError {
pointer: u32,
},
StateVersionMismatch {
parameter: TrieEntryVersion,
specification: TrieEntryVersion,
},
ChildStorageRootTrieDoesntExist,
BatchVerifyWithoutStarting,
AlreadyBatchVerify,
NoBatchVerify,
HostFunctionNotImplemented {
function: &'static str,
},
}Expand description
Reason why the Wasm blob isn’t conforming to the runtime environment.
Variants
Trap(Trap)
Error in the Wasm code execution.
AbortOnPanic
Runtime has called the ext_panic_handler_abort_on_panic_version_1 host function.
BadReturnValue
A non-i64 value has been returned by the Wasm entry point.
ReturnedPtrOutOfRange
The pointer and size returned by the Wasm entry point function are invalid.
Fields
UnresolvedFunctionCalled
Called a function that is unknown to the host.
Note: Can only happen if
allow_unresolved_importswastrue.
Fields
ParamDecodeError
Failed to decode a SCALE-encoded parameter.
ParamOutOfRange
One parameter is expected to point to a buffer, but the pointer is out of range of the memory of the Wasm VM.
Fields
Utf8Error
One parameter is expected to point to a UTF-8 string, but the buffer isn’t valid UTF-8.
Fields
NoActiveTransaction
Called ext_storage_rollback_transaction_version_1 or
ext_storage_commit_transaction_version_1 but no transaction was in progress.
FinishedWithPendingTransaction
Execution has finished while a transaction started with
ext_storage_start_transaction_version_1 was still in progress.
OutOfMemory
Error when allocating memory for a return type.
Fields
FreeError
Called ext_allocator_free_version_1 with an invalid pointer.
StateVersionMismatch
Mismatch between the state trie version provided as parameter and the state trie version found in the runtime specification.
Fields
parameter: TrieEntryVersionThe version passed as parameter.
specification: TrieEntryVersionThe version in the specification.
ChildStorageRootTrieDoesntExist
Called ext_default_child_storage_root_version_1 or
ext_default_child_storage_root_version_2 on a child trie that doesn’t exist.
BatchVerifyWithoutStarting
Runtime has tried to perform a signature batch verification before initiating a batch verification.
AlreadyBatchVerify
Runtime has tried to initiate a batch signatures verification while there was already one in progress.
NoBatchVerify
Runtime has tried to finish a batch signatures verification while none is in progress.
HostFunctionNotImplemented
The host function isn’t implemented.