Wasm runtimes can optionally contain a custom section (as defined in the official WebAssembly core specification).
This module is dedicated to finding the custom sections containing the runtime version.
Re-exports
pub use super::TrieEntryVersion;
Structs
- Core
Version - Buffer storing the SCALE-encoded core version.
- Core
Version Api - One API that the runtime supports.
- Core
Version Apis From Slice Err - Error potentially returned by
CoreVersionApisRefIter::from_slice_no_length. - Core
Version Apis RefIter - Iterator to a list of APIs. See
CoreVersionRef::apis. - Core
Version Ref - Runtime specification, once decoded.
- Embedded
Runtime Version Apis - Returns by
find_encoded_embedded_runtime_version_apis.
Enums
- Core
Version Error - Error while executing
Core_version. - Find
Embedded Runtime Version Error - Error returned by
find_embedded_runtime_version. - Find
Encoded Embedded Runtime Version Apis Error - Error returned by
find_encoded_embedded_runtime_version_apis.
Functions
- find_
embedded_ runtime_ version - Tries to find the custom section containing the runtime version and checks its validity.
- find_
encoded_ embedded_ runtime_ version_ apis - Tries to find the custom sections containing the runtime version and APIs.
- hash_
api_ name - Hashes the name of an API in order to be able to compare it to
CoreVersionApi::name_hash.