Wasm virtual machine, with automatic storage overlay.
The code in this module builds upon the functionalities of the host module and
implements some of the host function calls. In other words, it is an easier-to-use version of
the host module.
Most of the documentation of the host module also applies here.
In addition to the functionalities provided by the host module, the runtime_call module:
- Keeps track of the changes to the storage and off-chain storage made by the execution, and provides them at the end. Any storage access takes into account the intermediary list of changes.
- Automatically handles some externalities, such as calculating the Merkle root or storage transactions.
These additional features considerably reduces the number of externals concepts to plug to the virtual machine.
Re-exports
pub use host::Error as ErrorDetail;pub use host::LogEmitInfo;pub use host::LogEmitInfoHex;pub use host::LogEmitInfoStr;pub use host::StorageProofSizeBehavior;pub use trie::Nibble;pub use trie::TrieEntryVersion;
Structs
- Closest
Descendant Merkle Value - Obtaining the Merkle value of the closest descendant of a trie node is required in order to continue.
- Config
- Configuration for
run. - Error
- Error that can happen during the execution.
- LogEmit
- Report about a log entry being emitted.
- NextKey
- Fetching the key that follows a given one is required in order to continue.
- Offchain
Random Seed - Providing a random number is required in order to continue.
- Offchain
Storage Compare Set - Setting the value of an offchain storage value is required.
- Offchain
Storage Get - Loading an offchain storage value is required in order to continue.
- Offchain
Storage Set - Setting the value of an offchain storage value is required.
- Offchain
Submit Transaction - The runtime requests submitting a transaction.
- Offchain
Timestamp - Providing the current UNIX timestamp is required in order to continue.
- Signature
Verification - Verifying whether a signature is correct is required in order to continue.
- Storage
Changes - See
Success::storage_changes. - Storage
Get - Loading a storage value is required in order to continue.
- Success
- Execution is successful.
- Success
Virtual Machine - Function execution has succeeded. Contains the return value of the call.
Enums
- Offchain
Context - Runtime
Call - Current state of the execution.
- Trie
Change - Trie
Change Storage Value
Functions
- run
- Start running the WebAssembly virtual machine.