pub enum ExecOutcome {
Finished {
return_value: Result<Option<WasmValue>, Trap>,
},
Interrupted {
id: usize,
params: Vec<WasmValue>,
},
}Expand description
Outcome of the run function.
Variants
Finished
The execution has finished.
The state machine is now in a poisoned state, and calling run
will return RunErr::Poisoned.
Interrupted
The virtual machine has been paused due to a call to a host function.
This variant contains the identifier of the host function that is expected to be
called, and its parameters. When you call run again, you must
pass back the outcome of calling that function.
Note: The type of the return value of the function is called is not specified, as the user is supposed to know it based on the identifier. It is an error to call
runwith a value of the wrong type.