pub struct RequestProcess { /* private fields */ }Expand description
Object connected to the ClientMainTask and containing a request expecting an answer.
If this object is dropped before the request has been answered, an automatic “internal error” error response is automatically sent back.
Implementations
Sourceimpl RequestProcess
impl RequestProcess
Sourcepub fn request(&self) -> MethodCall<'_>
pub fn request(&self) -> MethodCall<'_>
Returns the request which must be processed.
The request is guaranteed to not be related to subscriptions in any way.
Sourcepub fn respond(self, response: Response<'_>)
pub fn respond(self, response: Response<'_>)
Indicate the response to the request to the ClientMainTask.
Has no effect if the ClientMainTask has been destroyed.
Sourcepub fn respond_null(self)
pub fn respond_null(self)
Indicate to the ClientMainTask that the response to the request is null.
Has no effect if the ClientMainTask has been destroyed.
Sourcepub fn fail(self, error: ErrorResponse<'_>)
pub fn fail(self, error: ErrorResponse<'_>)
Indicate to the ClientMainTask that the request should return an error.
Has no effect if the ClientMainTask has been destroyed.
Sourcepub fn fail_with_attached_json(self, error: ErrorResponse<'_>, json: &str)
pub fn fail_with_attached_json(self, error: ErrorResponse<'_>, json: &str)
Indicate to the ClientMainTask that the request should return an error.
This function is similar to RequestProcess, except that an additional JSON payload is
attached to the error.
Has no effect if the ClientMainTask has been destroyed.