pub enum BlockAnnounceOutcome<'a, TRq, TSrc, TBl> {
TooOld {
announce_block_height: u64,
finalized_block_height: u64,
},
AlreadyVerified(AnnouncedBlockKnown<'a, TRq, TSrc, TBl>),
AlreadyPending(AnnouncedBlockKnown<'a, TRq, TSrc, TBl>),
Unknown(AnnouncedBlockUnknown<'a, TRq, TSrc, TBl>),
InvalidHeader(Error),
}Expand description
Outcome of calling AllSync::block_announce.
Variants
TooOld
Announced block is too old to be part of the finalized chain.
It is assumed that all sources will eventually agree on the same finalized chain. Blocks whose height is inferior to the height of the latest known finalized block should simply be ignored. Whether or not this old block is indeed part of the finalized block isn’t verified, and it is assumed that the source is simply late.
If the announced block was the source’s best block, the state machine has been updated to take this information into account.
Fields
AlreadyVerified(AnnouncedBlockKnown<'a, TRq, TSrc, TBl>)
Announced block has already been successfully verified and is part of the non-finalized chain.
AlreadyPending(AnnouncedBlockKnown<'a, TRq, TSrc, TBl>)
Announced block is already known by the state machine but hasn’t been verified yet.
Unknown(AnnouncedBlockUnknown<'a, TRq, TSrc, TBl>)
Announced block isn’t in the state machine.
InvalidHeader(Error)
Failed to decode announce header.